@@ -1,3 +1,5 @@
+import os
+
 import pytest
 
 
@@ -12,6 +14,11 @@ from plangym.api_tests import (  # noqa: F401
 from plangym.control.balloon import BalloonEnv
 
 
+disable_balloon_tests = os.getenv("DISABLE_BALLOON_ENV", True)
+if disable_balloon_tests and str(disable_balloon_tests).lower() != "false":
+    pytest.skip("balloon_learning_environment tests are disabled", allow_module_level=True)
+
+
 @pytest.fixture(
     params=generate_test_cases(["BalloonLearningEnvironment-v0"], BalloonEnv),
     scope="module",
